@@ -1,14 +1,19 @@
 check_in <- function(x, values, name_x = "x") {
-
   if (length(x) != 1) {
     rlang::abort(paste0("`", name_x, "` must be a length-one vector."))
   }
 
-
   if (!x %in% values) {
     all_values <- paste0(paste0('"', values, '"'), collapse = ", ")
-    rlang::abort(paste0("`", name_x, "` must be one of ",
-                        all_values, '; not "', x, '".'))
+    rlang::abort(paste0(
+      "`",
+      name_x,
+      "` must be one of ",
+      all_values,
+      '; not "',
+      x,
+      '".'
+    ))
   }
 
   invisible(x)
@@ -26,8 +31,11 @@ check_binary <- function(x, name_x = "x") {
 
 check_not_null <- function(x, name_x = "x") {
   if (is.null(x)) {
-    rlang::abort(paste0("`", name_x,
-                        "` must be specified and can't be `NULL`."))
+    rlang::abort(paste0(
+      "`",
+      name_x,
+      "` must be specified and can't be `NULL`."
+    ))
   }
 
   invisible(x)
